@@ -563,6 +563,7 @@ midori_extension_load_from_folder (MidoriApp* app,
         g_assert (midori_extension_activate_gracefully (app, extension_path, "libapps." G_MODULE_SUFFIX, activate));
         g_assert (midori_extension_activate_gracefully (app, extension_path, "libdelayed-load." G_MODULE_SUFFIX, activate));
         g_assert (midori_extension_activate_gracefully (app, extension_path, "libtabby." G_MODULE_SUFFIX, activate));
+        g_assert (midori_extension_activate_gracefully (app, extension_path, "libflummi." G_MODULE_SUFFIX, activate));
     }
     else
     {
@@ -677,7 +678,8 @@ midori_extension_add_to_list (MidoriApp*       app,
     if (strcmp (filename, "libtransfers." G_MODULE_SUFFIX)
      && strcmp (filename, "libapps." G_MODULE_SUFFIX)
      && strcmp (filename, "libdelayed-load." G_MODULE_SUFFIX)
-     && strcmp (filename, "libtabby." G_MODULE_SUFFIX))
+     && strcmp (filename, "libtabby." G_MODULE_SUFFIX)
+     && strcmp (filename, "libflummi." G_MODULE_SUFFIX))
         katze_array_add_item (extensions, extension);
 
     g_object_unref (extensions);
