@@ -1042,7 +1042,7 @@ midori_search_action_get_editor (MidoriSearchAction* search_action,
     GtkWidget* entry_uri;
     GtkWidget* entry_token;
 
-    toplevel = gtk_widget_get_toplevel (search_action->treeview);
+    toplevel = search_action->treeview ? gtk_widget_get_toplevel (search_action->treeview) : NULL;
     dialog = gtk_dialog_new_with_buttons (
         new_engine ? _("Add search engine") : _("Edit search engine"),
         toplevel ? GTK_WINDOW (toplevel) : NULL,
